@@ -18,6 +18,7 @@ public:
 
 private:
     FMH::MODEL_LIST m_list;
+    QUrl m_url;
 };
 
 class CompressedFile : public QObject
@@ -45,6 +46,8 @@ public slots:
 
 signals:
     void urlChanged();
+    void extractionFinished(QUrl url);
+    void compressionFinished(QUrl url);
 };
 
 #endif // COMPRESSEDFILE_H
