@@ -149,7 +149,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterType<RecentFilesModel>(INDEX_URI, 1, 0, "RecentFiles");
     qmlRegisterType<DirInfo>(INDEX_URI, 1, 0, "DirInfo");
     qmlRegisterType<PathList>(INDEX_URI, 1, 0, "PathList");
-    //    qmlRegisterType<FolderConfig>(INDEX_URI, 1, 0, "FolderConfig");
+    qmlRegisterType<FolderConfig>(INDEX_URI, 1, 0, "FolderConfig");
     qmlRegisterType<FileProperties>(INDEX_URI, 1, 0, "FileProperties");
     qmlRegisterType<Permission>(INDEX_URI, 1, 0, "Permission");
 
